==> apache-camel-4.2.0-src.zip: apache-camel-4.2.0/components/camel-platform-http-vertx/src/main/java/org/apache/camel/component/platform/http/vertx/HttpRequestBodyHandler.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.platform.http.vertx;

import io.vertx.core.Future;
import io.vertx.core.Handler;
import io.vertx.ext.web.Route;
import io.vertx.ext.web.RoutingContext;
import org.apache.camel.Message;

/**
 * Abstraction to handle HTTP request body processing.
 */
abstract class HttpRequestBodyHandler {
    Handler<RoutingContext> delegate;

    HttpRequestBodyHandler(Handler<RoutingContext> delegate) {
        this.delegate = delegate;
    }

    /**
     * Performs any required configuration on a {@link Route}.
     *
     * @param route The route to configure
     */
    abstract void configureRoute(Route route);

    /**
     * Processes the incoming HTTP request body.
     *
     * @param  routingContext The {@link RoutingContext} for the HTTP request being processed
     * @param  message        The {@link Message} associated with the HTTP request being processed
     * @return                {@link Future} to determine when the HTTP request body has been fully processed
     */
    abstract Future<Void> handle(RoutingContext routingContext, Message message);
}

==> apache-camel-4.12.0-src.zip: apache-camel-4.12.0/components/camel-platform-http-vertx/src/main/java/org/apache/camel/component/platform/http/vertx/HttpRequestBodyHandler.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.platform.http.vertx;

import io.vertx.core.Future;
import io.vertx.core.Handler;
import io.vertx.ext.web.Route;
import io.vertx.ext.web.RoutingContext;
import org.apache.camel.Message;

/**
 * Abstraction to handle HTTP request body processing.
 */
abstract class HttpRequestBodyHandler {
    final Handler<RoutingContext> delegate;

    HttpRequestBodyHandler(Handler<RoutingContext> delegate) {
        this.delegate = delegate;
    }

    /**
     * Performs any required configuration on a {@link Route}.
     *
     * @param route The route to configure
     */
    abstract void configureRoute(Route route);

    /**
     * Processes the incoming HTTP request body.
     *
     * @param  routingContext The {@link RoutingContext} for the HTTP request being processed
     * @param  message        The {@link Message} associated with the HTTP request being processed
     * @return                {@link Future} to determine when the HTTP request body has been fully processed
     */
    abstract Future<Void> handle(RoutingContext routingContext, Message message);
}
